I2sTx

Struct I2sTx 

pub struct I2sTx<'d, Dm>
where Dm: DriverMode,
{ /* private fields */ }
I2S TX channel

Implementations

Source

impl<'d, Dm> I2sTx<'d, Dm>
where Dm: DriverMode,

pub fn write<TX: DmaTxBuffer>( self, buffer: TX, ) -> Result<I2sTxDmaTransfer<'d, Dm, TX>, (Error, Self, TX)>

Available on crate feature unstable only.

Perform a DMA write.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn apply_config( &mut self, tx_config: &UnitConfig, ) -> Result<(), ConfigError>

Change the I2S Tx unit configuration.